﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Infragistics.UltraChart.Shared.Styles;
using Infragistics.UltraChart.Resources.Appearance;
using Infragistics.UltraChart.Core.Layers;
using Infragistics.UltraChart.Core.Primitives;

namespace UltraChartColumnWithScatterChart
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();

            manufacturingUltraChart.TitleTop.Text = "Charge de travail de fabrication pour la période du ";
            manufacturingUltraChart.TitleBottom.Text = "Généré le: " + DateTime.Now.ToShortDateString();

            //Build a datatable with the desired columns
            DataTable workloadTable = new DataTable();
            workloadTable.Columns.Add("Semaine", typeof(string));       
            workloadTable.Columns.Add("HrsFabDispo", typeof(decimal));  
            workloadTable.Columns.Add("HrsFabPlanif", typeof(decimal));
            workloadTable.Columns.Add("LineValue", typeof(decimal)); 
            workloadTable.Columns.Add("SemaineCount", typeof(int));     

            int weekCounter = 0;

            //Fill the table from a custom weekly workload datatable
            Random rnd = new Random();
            for (int k = 0; k < 50; k++)
            {
                weekCounter = weekCounter + 1;
                workloadTable.Rows.Add(new Object[] { DateTime.Today.AddDays(k).ToString(), rnd.Next(-2500, 2500), rnd.Next(0, 1000), rnd.Next(1000, 2500), weekCounter });
            }

       
            //Composite chart type containing 2 layers
            manufacturingUltraChart.ChartType = ChartType.Composite;
            ChartArea myChartArea = new ChartArea();
            manufacturingUltraChart.CompositeChart.ChartAreas.Add(myChartArea);

            //First X axis to be used with the column chart (series A)
            AxisItem axisX = new AxisItem();
            axisX.OrientationType = AxisNumber.X_Axis;
            axisX.DataType = AxisDataType.String;
            axisX.SetLabelAxisType = SetLabelAxisType.GroupBySeries;
            axisX.Labels.ItemFormatString = "<ITEM_LABEL>";
            axisX.Labels.OrientationAngle =45;
            axisX.Labels.Orientation = TextOrientation.Custom;
            axisX.Labels.HorizontalAlign = StringAlignment.Far;
            axisX.Extent = 150;

            //Y axis to be used with both layers
            AxisItem axisY = new AxisItem();
            axisY.OrientationType = AxisNumber.Y_Axis;
            axisY.DataType = AxisDataType.Numeric;
            axisY.Labels.ItemFormatString = "<DATA_VALUE:0.#>";
            axisY.RangeType = AxisRangeType.Custom;
            axisY.RangeMin = -2500;
            axisY.RangeMax = 2500;

            //Axis 2 to support the scatter layer with numeric data
            AxisItem axisX2 = new AxisItem();
            axisX2.OrientationType = AxisNumber.X2_Axis;
            axisX2.DataType = AxisDataType.Numeric;
            axisX2.SetLabelAxisType = SetLabelAxisType.GroupBySeries;

            AxisItem axisX3 = new AxisItem();
            axisX3.OrientationType = AxisNumber.X_Axis;
            axisX3.DataType = AxisDataType.String;
            axisX3.SetLabelAxisType = SetLabelAxisType.ContinuousData;
            axisX3.Visible = false;


            //Add the axes to the chart area
            myChartArea.Axes.Add(axisX);
            myChartArea.Axes.Add(axisY);
            myChartArea.Axes.Add(axisX2);
            myChartArea.Axes.Add(axisX3);

            //First serie to display available manufacturing hours in a "column chart"
            NumericSeries seriesA = new NumericSeries();
            seriesA.Label = "HRS FAB DISPONIBLES";
            seriesA.Data.DataSource = workloadTable;
            seriesA.Data.LabelColumn = "Semaine";
            seriesA.Data.ValueColumn = "HrsFabDispo";
            seriesA.PEs.Add(new PaintElement(Color.Yellow));// Transparent));

            //Second serie to display planned manufacturing hours in a XY series (dotted line on a scatter layer)
            XYSeries seriesB = new XYSeries();
            seriesB.Label = "HRS PLANIF FAB/SAV/STOCK";
            seriesB.Data.DataSource = workloadTable;
            seriesB.Data.LabelColumn = "Semaine";
            seriesB.Data.ValueXColumn = "SemaineCount";
            seriesB.Data.ValueYColumn = "HrsFabPlanif";
            seriesB.PEs.Add(new PaintElement(Color.Red));


            NumericSeries seriesLine = new NumericSeries();
            seriesLine.Label = "Test";
            seriesLine.Data.DataSource = workloadTable;
            seriesLine.Data.LabelColumn = "Semaine";
            seriesLine.Data.ValueColumn = "LineValue";
            seriesLine.PEs.Add(new PaintElement(Color.Green));
           

            //Add the series to the chart
            manufacturingUltraChart.CompositeChart.Series.Add(seriesA);
            manufacturingUltraChart.CompositeChart.Series.Add(seriesB);
            manufacturingUltraChart.CompositeChart.Series.Add(seriesLine);

            //Add a layer for the column chart
            ChartLayerAppearance myColumnLayer = new ChartLayerAppearance();
            myColumnLayer.ChartType = ChartType.ColumnChart;
            myColumnLayer.ChartArea = myChartArea;
            myColumnLayer.AxisX = axisX;
            myColumnLayer.AxisY = axisY;
            myColumnLayer.Series.Add(seriesA);


            // Add a lyer for the line chart
            ChartLayerAppearance myLineLayer = new ChartLayerAppearance();
            myLineLayer.ChartType = ChartType.LineChart;// LineChart;
            myLineLayer.ChartArea = myChartArea;
            myLineLayer.AxisX = axisX3;
            myLineLayer.AxisY = axisY;
            myLineLayer.Series.Add(seriesLine);
            


            //Add a layer for the scatter chart
            ChartLayerAppearance myScatterLayer = new ChartLayerAppearance();
            myScatterLayer.ChartType = ChartType.ScatterChart;
            ((ScatterChartAppearance)myScatterLayer.ChartTypeAppearance).ConnectWithLines =   true;
            myScatterLayer.ChartArea = myChartArea;
            myScatterLayer.AxisX = axisX2;
            myScatterLayer.AxisY = axisY;
            myScatterLayer.Series.Add(seriesB);

            //Add the layers to the chart
            manufacturingUltraChart.CompositeChart.ChartLayers.Add(myColumnLayer);
            manufacturingUltraChart.CompositeChart.ChartLayers.Add(myScatterLayer);
            manufacturingUltraChart.CompositeChart.ChartLayers.Add(myLineLayer);

          
            //Add a legend for the scatter layer (planned manufacturing hours)
            CompositeLegend myLegend = new CompositeLegend();
            myLegend.ChartLayers.Add(myScatterLayer);
            myLegend.ChartLayers.Add(myLineLayer);
            myLegend.Bounds = new Rectangle(80, 1, 20, 10);
            myLegend.BoundsMeasureType = MeasureType.Percentage;
            myLegend.PE.ElementType = PaintElementType.Gradient;
            myLegend.PE.FillGradientStyle = GradientStyle.ForwardDiagonal;
            myLegend.PE.Fill = Color.CornflowerBlue;
            myLegend.PE.FillStopColor = Color.Transparent;
            myLegend.Border.CornerRadius = 10;
            myLegend.Border.Thickness = 0;
            manufacturingUltraChart.CompositeChart.Legends.Add(myLegend);

            manufacturingUltraChart.Tooltips.FormatString = "<SERIES_LABEL:MMM yyyy>" + Environment.NewLine + "<ITEM_LABEL>: <DATA_VALUE:00.##>";
        }

        private void manufacturingUltraChart_FillSceneGraph(object sender, Infragistics.UltraChart.Shared.Events.FillSceneGraphEventArgs e)
        {
            List<Box> listBox = new List<Box>();
            foreach (Primitive item in e.SceneGraph)
            {
                Box pl = item as Box;
                if (pl != null && pl.Series != null) listBox.Add(pl);

                Polyline line = item as Polyline;
                if (line != null)
                {
                    int k = 0;
                    foreach (DataPoint pp in line.points)
                    {
                        pp.point.X = listBox[k].rect.X + (listBox[k].rect.Width / 2);
                        k++;
                    }
                }
            }
        }
    }
}
